@@ -153,10 +153,16 @@ class CloudPods:
                 log.error(f"Failed to get /endpoints: Error. err msg is {str(e)}", exc_info=True)
                 return None
             endpoints=dict({})
+            if not rs_data:
+                log.error(f"Failed to get /endpoints for rs_data is None: Error. rs.text is {str(rs.text)}")
+                return None
             if "endpoints" not in rs_data.keys():
                 log.error(f"Failed to get /endpoints for endpoints not in rs_data.keys(): Error. rs.text is {str(rs.text)}")
                 return None
             for elem in rs_data["endpoints"]:
+                if not elem:
+                    log.error(f"Failed to get /endpoints for elem is None: Error. rs.text is {str(rs.text)}")
+                    return None
                 if "service_name" not in elem.keys():
                     log.error(f"Failed to get /endpoints for service_name not in elem.keys(): Error. rs.text is {str(rs.text)}")
                     return None
@@ -361,6 +367,9 @@ class CloudPods:
         elif "servers" in create_result.keys():
             # 多服务器创建成功
             for server_info in create_result["servers"]:
+                if not server_info:
+                    log.warning(f"未获取到server_info，返回结果: {server_info}")
+                    continue
                 if "body" not in server_info.keys():
                     log.warning(f"未获取到body，返回结果: {server_info}")
                     continue
@@ -430,6 +439,9 @@ class CloudPods:
     @enter_and_leave_function
     def get_server_ip(self, server_id):
         server = self.get_server_detail(server_id)
+        if not server:
+            log.warning(f"failed get server info by server name {server_id}, server info is {server}.")
+            return None
         if "server" not in server.keys():
             log.warning(f"failed get server info by server name {server_id}, server info is {server}.")
             return None
@@ -453,6 +465,9 @@ class CloudPods:
                 log.warning(f"Timeout Error: {timeout} seconds passed but server still not online: Error.")
                 return False
             server_detail = self.get_server_detail(server_id)
+            if not server_detail:
+                log.warning(f"Failed to get server detail: Error. server_detail is None")
+                return False
             if "server" in server_detail.keys() and "status" in server_detail["server"].keys():
                 if server_detail["server"]["status"] == "disk_fail":
                     log.warning(f"server_id: {server_id} disk_fail")
@@ -501,6 +516,9 @@ class CloudPods:
             rs = self.__session.get(url=url, params=payload, verify=False, timeout=600)
             try:
                 rs_data = rs.json()
+                if not rs_data:
+                    log.warning(f"Failed to get server_detail: Error. server_detail is: {rs_data}")
+                    return False
                 if "servers" not in rs_data.keys():
                     log.warning(f"Failed to get server_detail: Error. server_detail is: {rs_data}")
                     return False
@@ -700,11 +718,13 @@ if __name__ == '__main__':
     # print(server_ip)
     # cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
     cloudpods = CloudPods('https://10.20.40.101:30500/v3', 'admin', 'jSj@2008')
+    # rs=cloudpods.wait_for_server_is_deleted("dddc5d9a-6bf5-4e37-860b-ec485a5a6823")
+    # print(rs)
     # rs=cloudpods.get_baremetal_hosts()
     # for elem in rs:
     #     if elem["id"]=="5d6dfb67-db25-43d2-8057-116769fb3abf":
     #         print(elem)
-    rs = cloudpods.get_can_deploy_server_host_num("aarch64","uefi")
+    rs = cloudpods.get_can_deploy_server_host_num("x86_64","bios")
     print(rs)
     # print(len(rs))
     # print(rs[0])
